/*
 * Copyright 2008 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.zxing.client.j2se;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.LuminanceSource;
import com.google.zxing.MultiFormatReader;
import com.google.zxing.MultiFormatWriter;
import com.google.zxing.ReaderException;
import com.google.zxing.Result;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.HybridBinarizer;

import java.awt.Container;
import java.awt.GridLayout;
import java.awt.Image;
import java.awt.TextArea;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.imageio.ImageIO;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * <p>
 * Simple GUI frontend to the library. Right now, only decodes a local file.
 * This definitely needs some improvement. Just throwing something down to
 * start.
 * </p>
 * 
 * @author Sean Owen
 */
//ñʽ Encoder.java static final String DEFAULT_BYTE_MODE_ENCODING ="UTF-8"
//ͼƬСļ
public final class GUIRunner extends JFrame implements ActionListener {

	private final JLabel imageLabel;
	private final TextArea textArea;
	private final JButton sel_button;
	private final JButton generate_button;
	private final JLabel label2;
	private final TextArea textArea2;

	private GUIRunner() {
		imageLabel = new JLabel();
		textArea = new TextArea();
		textArea.setEditable(false);
//		textArea.setLineWrap(true);
//		textArea.setMaximumSize(new Dimension(400, 200));
		label2=new JLabel("ҪϢ");
		textArea2 =new TextArea();
		// Button
		sel_button = new JButton("ѡͼƬ");
		sel_button.addActionListener(this);
		generate_button=new JButton("ɶά");
		generate_button.addActionListener(this);
		Container panel = new JPanel(new GridLayout(2,1));
		//panel.setLayout(new FlowLayout());//new GridLayout(2,1)
		panel.add(imageLabel);//һһ
		JPanel panel2=new JPanel(new GridLayout(4,1));//2һ
		panel2.add(textArea);
		panel2.add(label2);
		panel2.add(textArea2);
		JPanel panel3=new JPanel(new GridLayout(1,2));
		panel3.add(sel_button);
		panel3.add(generate_button);
		panel2.add(panel3);
		panel.add(panel2);
		setTitle("ά_Powered by Zxing (C)xuenhua");
		setSize(420, 420);
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setContentPane(panel);
		setLocationRelativeTo(null);
	}

	public static void main(String[] args) throws MalformedURLException {
		GUIRunner runner = new GUIRunner();
		runner.setVisible(true);
		//runner.chooseImage();
	}

	private void chooseImage() throws MalformedURLException {
		JFileChooser fileChooser = new JFileChooser();
		fileChooser.showOpenDialog(this);
		File file = fileChooser.getSelectedFile();	
		Icon imageIcon = new ImageIcon(file.toURI().toURL());
		if(imageIcon.getIconWidth()>200){//תߴ
			Image image=null;
			try {
				image = ImageIO.read(file);
			} catch (IOException ioe) {
				System.out.println( ioe.toString());
			}
			if (image == null) {
				System.out.println("Could not decode image");
			}
			Image scaledImage=image.getScaledInstance(200,200,Image.SCALE_DEFAULT); 
			imageIcon=new ImageIcon(scaledImage); 
		}

//		setSize(imageIcon.getIconWidth(), imageIcon.getIconHeight() + 100);
		imageLabel.setIcon(imageIcon);
		String decodeText = getDecodeText(file);
		textArea.setText(decodeText);
	}
	private static String getDecodeText(File file) {
		BufferedImage image;
		try {
			image = ImageIO.read(file);
		} catch (IOException ioe) {
			return ioe.toString();
		}
		if (image == null) {
			return "Could not decode image";
		}
		LuminanceSource source = new BufferedImageLuminanceSource(image);
		BinaryBitmap bitmap = new BinaryBitmap(new HybridBinarizer(source));
		Result result;
		try {
			result = new MultiFormatReader().decode(bitmap);
		} catch (ReaderException re) {
			return re.toString();
		}
		return result.getText();
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		try {
			if(e.getActionCommand()=="ѡͼƬ"){
				chooseImage();
			}
			if(e.getActionCommand()=="ɶά"){
				BitMatrix bitMatrix;
				String str=textArea2.getText();
				String user_dir=System.getProperty("user.dir");
				//long timestamp=System.currentTimeMillis();
				SimpleDateFormat  sfd=new SimpleDateFormat ("yyyy-MM-dd-hh-mm-ss");
				String timestamp=sfd.format(new Date());

				
				String path=user_dir+"\\qr-"+timestamp+ ".png";
				try {
					bitMatrix = new MultiFormatWriter().encode
					(str, BarcodeFormat.QR_CODE, 200, 200);//ͼƬС
					File file = new File(path);	
					if(!file.exists()) {
						file.createNewFile();
					}
						MatrixToImageWriter.writeToFile(bitMatrix, "png", file);
						textArea.setText("άɳɹ\n"+path);
					} catch (IOException eIO) {
					eIO.printStackTrace();
					} catch (WriterException e1) {
					e1.printStackTrace();
					}
			}
		} catch (MalformedURLException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
	}

}
